@@ -965,11 +965,12 @@ sub rollback ( $self, $cb ) {
 }
 
 # QUOTE
-# https://www.postgresql.org/docs/current/static/sql-syntax-lexical.html
 sub quote_id ( $self, $id ) {
-    $id =~ s/"/""/smg;
+    return $self->{handle}->quote_id($id);
+}
 
-    return qq["$id"];
+sub quote ( $self, $var, $type = undef ) {
+    return $self->{handle}->quote( $var, $type );
 }
 
 1;
